summaryrefslogtreecommitdiff
path: root/clients/xzwrite/destlist.c
diff options
context:
space:
mode:
Diffstat (limited to 'clients/xzwrite/destlist.c')
-rw-r--r--clients/xzwrite/destlist.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/clients/xzwrite/destlist.c b/clients/xzwrite/destlist.c
index 1cc91e1..8621922 100644
--- a/clients/xzwrite/destlist.c
+++ b/clients/xzwrite/destlist.c
@@ -23,7 +23,7 @@ static DynObject dests;
extern Defaults defs;
static void get_dest_from_file(), _get_default_dest();
-static int sort_dest_func();
+static int sort_dest_func(const void *, const void *);
/* A function for debugging */
void dest_print()
@@ -366,12 +366,13 @@ void dest_add_reply(notice)
list = dest_text();
num = dest_num();
- /* A hack so local-rhs is less annoying */
+
+ /* A hack so local-realm is less annoying */
{
char *r;
r = strchr(notice->z_sender, '@');
- if (r && ! strcmp(r+1, ZGetRhs(NULL)))
+ if (r && ! strcmp(r+1, ZGetRealm()))
*r = '\0';
}